@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2006-2007 Ed Schouten <ed@fxq.nl>
+ * Copyright (c) 2006-2008 Ed Schouten <ed@80386.nl>
  * All rights reserved.
  * 
  * Redistribution and use in source and binary forms, with or without
@@ -489,12 +489,12 @@ gui_playq_song_select(void)
 }
 
 int
-gui_playq_searchnext(const regex_t *match)
+gui_playq_searchnext(const struct vfsmatch *vm)
 {
 	int ret;
 
 	playq_lock();
-	ret = gui_vfslist_searchnext(win_playq, match);
+	ret = gui_vfslist_searchnext(win_playq, vm);
 	playq_unlock();
 	
 	return (ret);
